@@ -18,10 +18,10 @@
 #
 import sys
 import os
-from configparser import ConfigParser
 
 sys.path.insert(0, 'src')
 from fuglu.funkyconsole import FunkyConsole
+from fuglu.shared import FuConfigParser
 
 fc = FunkyConsole()
 
@@ -29,7 +29,7 @@ fugluconfigfile = '/etc/fuglu/fuglu.conf'
 dconfdir = '/etc/fuglu/conf.d'
 
 
-currentconfig = ConfigParser()
+currentconfig = FuConfigParser()
 currentconfig.read_file(open(fugluconfigfile))
 
 # load conf.d
@@ -39,7 +39,7 @@ if os.path.isdir(dconfdir):
     readfiles = currentconfig.read(configfiles)
     print('Read additional files: %s' % readfiles)
 
-newconfig = ConfigParser()
+newconfig = FuConfigParser()
 newconfig.read('conf/fuglu.conf.dist')
 
 newsections = newconfig.sections()
