@@ -936,10 +936,13 @@ class MilterSession(lm.MilterProtocol):
         self.log('Connect from %s:%d (%s) with family: %s, dict: %s' % (ip, port,
                                                               hostname, family, str(command_dict)))
         self.store_info_from_dict(command_dict)
-        if family not in (b'4', b'6'):  # we don't handle unix socket
+        if family not in (b'4', b'6', b'U'):
             self.logger.warning('Return temporary fail since family is: %s' % force_uString(family))
             self.logger.warning(u'command dict is: %s' % MilterSession.dict_unicode(command_dict))
             return lm.TEMPFAIL
+        elif family == b"U":
+            # we handle unix socket, but print debug message since it's not tested well
+            self.logger.debug(f'Handle unix socket connection')
         if hostname is None or force_uString(hostname) == u'[%s]' % force_uString(ip):
             hostname = u'unknown'
 
