@@ -22,11 +22,12 @@ import os
 import re
 import typing as tp
 
-from fuglu.shared import Suspect, apply_template
+from fuglu.shared import Suspect, apply_template, get_outgoing_helo
 from fuglu.protocolbase import ProtocolHandler, BasicTCPServer
 from fuglu.connectors.check import HealthCheckSuspect
 from email.header import Header
 from fuglu.stringencode import force_bString, force_uString
+from fuglu.bounce import FugluSMTPClient
 
 
 mailregex = re.compile(r"^[^@<>]+<((?:\".*\"|[^\"<>@\s]+)@[^<>@\s]+)>(\s.*)?$",
@@ -117,15 +118,22 @@ class SMTPHandler(ProtocolHandler):
         else:
             msgcontent = buildmsgsource(suspect)
 
-        self.logger.info(f"{suspect.id} reinject message size: {len(msgcontent)}")
 
-        targethost = self.config.get('main', 'outgoinghost')
+        targethost: str = self.config.get('main', 'outgoinghost')
         if targethost == '${injecthost}':
             targethost = self.socket.getpeername()[0]
-        client = FUSMTPClient(targethost, self.config.getint('main', 'outgoingport'))
-        helo = self.config.get('main', 'outgoinghelo')
-        if helo.strip() == '':
-            helo = socket.gethostname()
+        elif targethost.startswith("$"):
+            # extract target host from environment variable
+            env_targethost = os.environ[targethost[1:]]
+            if not env_targethost:
+                raise ValueError(f"Could not extract outgoing host from environment var '{targethost}'")
+            targethost = env_targethost
+
+        outgoingport = self.config.getint('main', 'outgoingport')
+        self.logger.info(f"{suspect.id} reinject message with size: {len(msgcontent)} to {targethost}:{outgoingport}")
+
+        client = FugluSMTPClient(targethost, outgoingport)
+        helostring = get_outgoing_helo(self.config)
 
         # if there are SMTP options (SMTPUTF8, ...) then use ehlo
         mail_options = list(suspect.smtp_options)
@@ -154,12 +162,13 @@ class SMTPHandler(ProtocolHandler):
 
         serveranswer = None
         responsecode = None
+        queueid = None
         try:
             if mail_options:
-                client.ehlo(helo)
+                client.ehlo(helostring)
             else:
-                client.helo(helo)
-
+                client.helo(helostring)
+            
             # for sending, make sure the string to sent is byte string
             client.sendmail(force_uString(suspect.from_address),
                             force_uString(suspect.recipients),
@@ -169,6 +178,7 @@ class SMTPHandler(ProtocolHandler):
             # servercode=client.lastservercode
             responsecode = 250
             serveranswer = client.lastserveranswer
+            queueid = client.queueid
         except (smtplib.SMTPHeloError, smtplib.SMTPRecipientsRefused,
                 smtplib.SMTPSenderRefused, smtplib.SMTPDataError) as e:
             if isinstance(e, smtplib.SMTPResponseException):
@@ -191,12 +201,12 @@ class SMTPHandler(ProtocolHandler):
             serveranswer = ''
 
         # make sure serveranswer is unicode (could be bytes, error, ...)
-        return responsecode, force_uString(serveranswer)
+        return responsecode, force_uString(serveranswer), queueid
 
     def get_suspect(self, **kwargs):
         success = self.sess.getincomingmail()
         if not success and not self.sess.healthcheck:
-            self.logger.error('incoming smtp transfer did not finish')
+            self.logger.warning('incoming smtp transfer did not finish')
             return None
 
         sess = self.sess
@@ -222,8 +232,9 @@ class SMTPHandler(ProtocolHandler):
         return suspect
 
     def commitback(self, suspect):
-        injectcode, injectanswer = self.re_inject(suspect)
+        injectcode, injectanswer, queueid = self.re_inject(suspect)
         suspect.set_tag("injectanswer", injectanswer)
+        suspect.set_tag("injectqueueid", queueid)
 
         if injectcode == 250:
             values = dict(injectanswer=injectanswer)
@@ -248,20 +259,6 @@ class SMTPHandler(ProtocolHandler):
         self.sess.endsession(250, "healthcheck")
 
 
-class FUSMTPClient(smtplib.SMTP):
-
-    """
-    This class patches the sendmail method of SMTPLib so we can get the return message from postfix
-    after we have successfully re-injected. We need this so we can find out the new Queue-ID
-    """
-
-    def getreply(self):
-        code, response = smtplib.SMTP.getreply(self)
-        self.lastserveranswer = response
-        self.lastservercode = code
-        return code, response
-
-
 class SMTPServer(BasicTCPServer):
 
     def __init__(self, controller, port=10125, address="127.0.0.1"):
@@ -403,7 +400,7 @@ class SMTPSession(object):
                             return False
                 else:
                     # EOF
-                    self.logger.error("EOF, something went wrong!")
+                    self.logger.warning("EOF, something went wrong!")
                     return False
     
     
