@@ -286,7 +286,7 @@ class MainController(DefConfigMixin):
             'nobouncefile': {
                 'section': 'main',
                 'description': 'list of domains to which no bounces will be sent',
-                'default': '/etc/fuglu/rules/nobounce.txt',
+                'default': '${confdir}/rules/nobounce.txt',
             },
 
             'debuginfoheader': {
@@ -520,6 +520,21 @@ class MainController(DefConfigMixin):
                 'section': 'PluginAlias',
             },
 
+            'p_blwl': {
+                'default': "fuglu.plugins.p_blwl.BlockWelcomeList",
+                'section': 'PluginAlias',
+            },
+
+            'm_blwl': {
+                'default': "fuglu.plugins.p_blwl.BlockWelcomeMilter",
+                'section': 'PluginAlias',
+            },
+
+            'a_autolist': {
+                'default': "fuglu.plugins.p_blwl.AutoListAppender",
+                'section': 'PluginAlias',
+            },
+
             'archive': {
                 'default': "fuglu.plugins.archive.ArchivePlugin",
                 'section': 'PluginAlias',
@@ -530,21 +545,21 @@ class MainController(DefConfigMixin):
                 'section': 'PluginAlias',
             },
 
+            'bacn': {
+                'default': "fuglu.plugins.bacn.BACN",
+                'section': 'PluginAlias',
+            },
+
+            'm_ca': {
+                'default': "fuglu.plugins.call_ahead.AddressCheck",
+                'section': 'PluginAlias',
+            },
+
             'clamav': {
                 'default': "fuglu.plugins.clamav.ClamavPlugin",
                 'section': 'PluginAlias',
             },
 
-            'spamassassin': {
-                'default': "fuglu.plugins.sa.SAPlugin",
-                'section': 'PluginAlias',
-            },
-
-            'vacation': {
-                'default': "fuglu.plugins.vacation.VacationPlugin",
-                'section': 'PluginAlias',
-            },
-
             'actionoverride': {
                 'default': "fuglu.plugins.decision.ActionOverridePlugin",
                 'section': 'PluginAlias',
@@ -555,6 +570,191 @@ class MainController(DefConfigMixin):
                 'section': 'PluginAlias',
             },
 
+            'filterdecision': {
+                'default': "fuglu.plugins.decision.FilterDecision",
+                'section': 'PluginAlias',
+            },
+
+            'rcptrewrite': {
+                'default': "fuglu.plugins.decision.RcptRewrite",
+                'section': 'PluginAlias',
+            },
+
+            'condrcptapp': {
+                'default': "fuglu.plugins.decision.ConditionalRcptAppend",
+                'section': 'PluginAlias',
+            },
+
+            'delay': {
+                'default': "fuglu.plugins.delay.DelayPlugin",
+                'section': 'PluginAlias',
+            },
+
+            'dkimsign': {
+                'default': "fuglu.plugins.domainauth.DKIMSignPlugin",
+                'section': 'PluginAlias',
+            },
+
+            'dkimverify': {
+                'default': "fuglu.plugins.domainauth.DKIMVerifyPlugin",
+                'section': 'PluginAlias',
+            },
+
+            'arcverify': {
+                'default': "fuglu.plugins.domainauth.ARCVerifyPlugin",
+                'section': 'PluginAlias',
+            },
+
+            'dmarc': {
+                'default': "fuglu.plugins.domainauth.DMARCPlugin",
+                'section': 'PluginAlias',
+            },
+
+            'spf': {
+                'default': "fuglu.plugins.domainauth.SPFPlugin",
+                'section': 'PluginAlias',
+            },
+
+            'spfout': {
+                'default': "fuglu.plugins.domainauth.SPFOutPlugin",
+                'section': 'PluginAlias',
+            },
+
+            'srs': {
+                'default': "fuglu.plugins.domainauth.SenderRewriteScheme",
+                'section': 'PluginAlias',
+            },
+
+            'domainauth': {
+                'default': "fuglu.plugins.domainauth.DomainAuthPlugin",
+                'section': 'PluginAlias',
+            },
+
+            'spearphish': {
+                'default': "fuglu.plugins.domainauth.SpearPhishPlugin",
+                'section': 'PluginAlias',
+            },
+
+            'fuzorcheck': {
+                'default': "fuglu.plugins.fuzor.FuzorCheck",
+                'section': 'PluginAlias',
+            },
+
+            'fuzorreport': {
+                'default': "fuglu.plugins.fuzor.FuzorReport",
+                'section': 'PluginAlias',
+            },
+
+            'a_fuzorreport': {
+                'default': "fuglu.plugins.fuzor.FuzorReportAppender",
+                'section': 'PluginAlias',
+            },
+
+            'fuzorprint': {
+                'default': "fuglu.plugins.fuzor.FuzorPrint",
+                'section': 'PluginAlias',
+            },
+
+            'geoip': {
+                'default': "fuglu.plugins.geoip.GeoIPLookup",
+                'section': 'PluginAlias',
+            },
+
+            'm_ivmsg': {
+                'default': "fuglu.plugins.ivmsg.IVMSendgrid",
+                'section': 'PluginAlias',
+            },
+
+            'ivmfeed': {
+                'default': "fuglu.plugins.ivmsg.IVMFeed",
+                'section': 'PluginAlias',
+            },
+
+            'knownsubject': {
+                'default': "fuglu.plugins.knownsubject.KnownSubject",
+                'section': 'PluginAlias',
+            },
+
+            'a_knownsubject': {
+                'default': "fuglu.plugins.knownsubject.KnownSubjectAppender",
+                'section': 'PluginAlias',
+            },
+
+            'imapcopy': {
+                'default': "fuglu.plugins.mailcopy.IMAPCopy",
+                'section': 'PluginAlias',
+            },
+
+            'mailfeed': {
+                'default': "fuglu.plugins.mailcopy.MailFeed",
+                'section': 'PluginAlias',
+            },
+
+            'autoreport': {
+                'default': "fuglu.plugins.mailcopy.AutoReport",
+                'section': 'PluginAlias',
+            },
+
+            'm_msgsize': {
+                'default': "fuglu.plugins.messagesize.MessageSize",
+                'section': 'PluginAlias',
+            },
+
+            'm_originpolicy': {
+                'default': "fuglu.plugins.originpolicy.OriginPolicy",
+                'section': 'PluginAlias',
+            },
+
+            'm_sdrdomrules': {
+                'default': "fuglu.plugins.outpolicy.SenderDomainRules",
+                'section': 'PluginAlias',
+            },
+
+            'm_nobounce': {
+                'default': "fuglu.plugins.outpolicy.NoBounce",
+                'section': 'PluginAlias',
+            },
+
+            'trapintercept': {
+                'default': "fuglu.plugins.outpolicy.TrapIntercept",
+                'section': 'PluginAlias',
+            },
+
+            'fuzorratelimit': {
+                'default': "fuglu.plugins.outpolicy.FuzorRateLimit",
+                'section': 'PluginAlias',
+            },
+
+            'm_pfqdratelimit': {
+                'default': "fuglu.plugins.outpolicy.PFQDRateLimit",
+                'section': 'PluginAlias',
+            },
+
+            'm_accessrestrictions': {
+                'default': "fuglu.plugins.restrictions.AccessRestrictions",
+                'section': 'PluginAlias',
+            },
+
+            'm_accessrestrictionsnwl': {
+                'default': "fuglu.plugins.restrictions.AccessRestrictionsNWL",
+                'section': 'PluginAlias',
+            },
+
+            'rspamd': {
+                'default': "fuglu.plugins.rspamd.RSpamdPlugin",
+                'section': 'PluginAlias',
+            },
+
+            'spamassassin': {
+                'default': "fuglu.plugins.sa.SAPlugin",
+                'section': 'PluginAlias',
+            },
+
+            'vacation': {
+                'default': "fuglu.plugins.vacation.VacationPlugin",
+                'section': 'PluginAlias',
+            },
+
             'icap': {
                 'default': "fuglu.plugins.antivirus.ICAPPlugin",
                 'section': 'PluginAlias',
@@ -575,18 +775,63 @@ class MainController(DefConfigMixin):
                 'section': 'PluginAlias',
             },
 
-            'dkimsign': {
-                'default': "fuglu.plugins.domainauth.DKIMSignPlugin",
+            'm_enforcetls': {
+                'default': "fuglu.plugins.tlspolicy.EnforceTLS",
                 'section': 'PluginAlias',
             },
 
-            'dkimverify': {
-                'default': "fuglu.plugins.domainauth.DKIMVerifyPlugin",
+            'm_tlssender': {
+                'default': "fuglu.plugins.tlspolicy.TLSSender",
                 'section': 'PluginAlias',
             },
 
-            'spf': {
-                'default': "fuglu.plugins.domainauth.SPFPlugin",
+            'uriextract': {
+                'default': "fuglu.plugins.uriextract.URIExtract",
+                'section': 'PluginAlias',
+            },
+
+            'emailextract': {
+                'default': "fuglu.plugins.uriextract.EmailExtract",
+                'section': 'PluginAlias',
+            },
+
+            'domainaction': {
+                'default': "fuglu.plugins.uriextract.DomainAction",
+                'section': 'PluginAlias',
+            },
+
+            'emailaction': {
+                'default': "fuglu.plugins.uriextract.EmailAction",
+                'section': 'PluginAlias',
+            },
+
+            'a_uriextract': {
+                'default': "fuglu.plugins.uriextract.URIExtractAppender",
+                'section': 'PluginAlias',
+            },
+
+            'a_emailextract': {
+                'default': "fuglu.plugins.uriextract.EmailExtractAppender",
+                'section': 'PluginAlias',
+            },
+
+            'a_elasticlogger': {
+                'default': "fuglu.plugins.a_logging.ElasticLogger",
+                'section': 'PluginAlias',
+            },
+
+            'a_plugintime': {
+                'default': "fuglu.plugins.a_statsd.PluginTime",
+                'section': 'PluginAlias',
+            },
+
+            'a_msgstatus': {
+                'default': "fuglu.plugins.a_statsd.MessageStatus",
+                'section': 'PluginAlias',
+            },
+
+            'a_mststatusrcpt': {
+                'default': "fuglu.plugins.a_statsd.MessageStatusPerRecipient",
                 'section': 'PluginAlias',
             },
         }
@@ -1392,7 +1637,6 @@ class MainController(DefConfigMixin):
         for mpluginlist in self.milterdict.values():
             if mpluginlist:
                 milterplugins.extend(mpluginlist)
-        print(f"propagate... milterplugins: {milterplugins}")
 
         allplugs = self.plugins + self.prependers + self.appenders + milterplugins
         remove_plugin = []
