@@ -1,11 +1,12 @@
+# -*- coding: utf-8 -*-
 # This software is provided 'as-is', without any express or implied
 # warranty.  In no event will the author be held liable for any damages
 # arising from the use of this software.
-# 
+#
 # Permission is granted to anyone to use this software for any purpose,
 # including commercial applications, and to alter it and redistribute it
 # freely, subject to the following restrictions:
-# 
+#
 # 1. The origin of this software must not be misrepresented; you must not
 #    claim that you wrote the original software. If you use this software
 #    in a product, an acknowledgment in the product documentation would be
@@ -13,14 +14,14 @@
 # 2. Altered source versions must be plainly marked as such, and must not be
 #    misrepresented as being the original software.
 # 3. This notice may not be removed or altered from any source distribution.
-# 
+#
 # Copyright (c) 2008 Greg Hewgill http://hewgill.com
 
 import base64
 import hashlib
 import re
 import time
-
+from fuglu.stringencode import force_bString, force_bfromc, force_cfromb
 
 __all__ = [
     "Simple",
@@ -33,7 +34,9 @@ __all__ = [
     "verify",
 ]
 
-class Simple:
+
+class Simple(object):
+
     """Class that represents the "simple" canonicalization algorithm."""
 
     name = "simple"
@@ -48,7 +51,9 @@ class Simple:
         # Ignore all empty lines at the end of the message body.
         return re.sub("(\r\n)*$", "\r\n", body)
 
-class Relaxed:
+
+class Relaxed(object):
+
     """Class that represents the "relaxed" canonicalization algorithm."""
 
     name = "relaxed"
@@ -59,7 +64,7 @@ class Relaxed:
         # Unfold all header lines.
         # Compress WSP to single space.
         # Remove all WSP at the start or end of the field value (strip).
-        return [(x[0].lower(), re.sub(r"\s+", " ", re.sub("\r\n", "", x[1])).strip()+"\r\n") for x in headers]
+        return [(x[0].lower(), re.sub(r"\s+", " ", re.sub("\r\n", "", x[1])).strip() + "\r\n") for x in headers]
 
     @staticmethod
     def canonicalize_body(body):
@@ -68,30 +73,41 @@ class Relaxed:
         # Ignore all empty lines at the end of the message body.
         return re.sub("(\r\n)*$", "\r\n", re.sub(r"[\x09\x20]+", " ", re.sub("[\\x09\\x20]+\r\n", "\r\n", body)))
 
+
 class DKIMException(Exception):
+
     """Base class for DKIM errors."""
     pass
 
+
 class InternalError(DKIMException):
+
     """Internal error in dkim module. Should never happen."""
     pass
 
+
 class KeyFormatError(DKIMException):
+
     """Key format error while parsing an RSA public or private key."""
     pass
 
+
 class MessageFormatError(DKIMException):
+
     """RFC822 message format error."""
     pass
 
+
 class ParameterError(DKIMException):
+
     """Input parameter error."""
     pass
 
+
 def _remove(s, t):
     i = s.find(t)
     assert i >= 0
-    return s[:i] + s[i+len(t):]
+    return s[:i] + s[i + len(t):]
 
 INTEGER = 0x02
 BIT_STRING = 0x03
@@ -131,6 +147,7 @@ ASN1_RSAPrivateKey = [
     ])
 ]
 
+
 def asn1_parse(template, data):
     """Parse a data structure according to ASN.1 template.
 
@@ -160,23 +177,25 @@ def asn1_parse(template, data):
                     i += 1
                 r.append(n)
             elif tag == BIT_STRING:
-                r.append(data[i:i+length])
+                r.append(data[i:i + length])
                 i += length
             elif tag == NULL:
                 assert length == 0
                 r.append(None)
             elif tag == OBJECT_IDENTIFIER:
-                r.append(data[i:i+length])
+                r.append(data[i:i + length])
                 i += length
             elif tag == SEQUENCE:
-                r.append(asn1_parse(t[1], data[i:i+length]))
+                r.append(asn1_parse(t[1], data[i:i + length]))
                 i += length
             else:
                 raise KeyFormatError("Unexpected tag in template: %02x" % tag)
         else:
-            raise KeyFormatError("Unexpected tag (got %02x, expecting %02x)" % (tag, t[0]))
+            raise KeyFormatError(
+                "Unexpected tag (got %02x, expecting %02x)" % (tag, t[0]))
     return r
 
+
 def asn1_length(n):
     """Return a string representing a field length in ASN.1 format."""
     assert n >= 0
@@ -188,6 +207,7 @@ def asn1_length(n):
         n >>= 8
     return r
 
+
 def asn1_build(node):
     """Build an ASN.1 data structure based on pairs of (type, data)."""
     if node[0] == OCTET_STRING:
@@ -209,6 +229,7 @@ def asn1_build(node):
 HASHID_SHA1 = "\x2b\x0e\x03\x02\x1a"
 HASHID_SHA256 = "\x60\x86\x48\x01\x65\x03\x04\x02\x01"
 
+
 def str2int(s):
     """Convert an octet string to an integer. Octet string assumed to represent a positive integer."""
     r = 0
@@ -216,7 +237,8 @@ def str2int(s):
         r = (r << 8) | ord(c)
     return r
 
-def int2str(n, length = -1):
+
+def int2str(n, length=-1):
     """Convert an integer to an octet string. Number must be positive.
 
     @param n: Number to convert.
@@ -229,11 +251,13 @@ def int2str(n, length = -1):
     while length < 0 or len(r) < length:
         r.append(chr(n & 0xff))
         n >>= 8
-        if length < 0 and n == 0: break
+        if length < 0 and n == 0:
+            break
     r.reverse()
     assert length < 0 or len(r) == length
     return r
 
+
 def rfc822_parse(message):
     """Parse a message in RFC822 format.
 
@@ -249,43 +273,34 @@ def rfc822_parse(message):
     i = 0
     while i < len(lines):
         if len(lines[i]) == 0:
-            # End of headers, return what we have plus the body, excluding the blank line.
+            # End of headers, return what we have plus the body, excluding the
+            # blank line.
             i += 1
             break
         if re.match(r"[\x09\x20]", lines[i][0]):
-            headers[-1][1] += lines[i]+"\r\n"
+            headers[-1][1] += lines[i] + "\r\n"
         else:
             m = re.match(r"([\x21-\x7e]+?):", lines[i])
             if m is not None:
-                headers.append([m.group(1), lines[i][m.end(0):]+"\r\n"])
+                headers.append([m.group(1), lines[i][m.end(0):] + "\r\n"])
             elif lines[i].startswith("From "):
                 pass
             else:
-                raise MessageFormatError("Unexpected characters in RFC822 header: %s" % lines[i])
+                raise MessageFormatError(
+                    "Unexpected characters in RFC822 header: %s" % lines[i])
         i += 1
-    return (headers, "\r\n".join(lines[i:]))
+    return headers, "\r\n".join(lines[i:])
+
 
 def dnstxt(name):
-    """Return a TXT record associated with a DNS name."""
-    #PATCH:
-    #return fake dkim key for fuglu.org
-    if name.endswith('testfuglu.org.'):
-        k=''
-        for line in open('testdata/dkim/testfuglu.org.public'):
-            if line.startswith('---'):
-                continue
-            k=k+line.strip()
-            
-        record="v=DKIM1; k=rsa; p=%s"%k
-        return record
-    
-    import dns.resolver    
+    import dns.resolver
     a = dns.resolver.query(name, dns.rdatatype.TXT)
     for r in a.response.answer:
         if r.rdtype == dns.rdatatype.TXT:
             return "".join(r.items[0].strings)
     return None
 
+
 def fold(header):
     """Fold a header line into multiple crlf-separated lines at column 72."""
     i = header.rfind("\r\n ")
@@ -305,6 +320,7 @@ def fold(header):
         header = header[j:]
     return pre + header
 
+
 def sign(message, selector, domain, privkey, identity=None, canonicalize=(Simple, Simple), include_headers=None, length=False, debuglog=None):
     """Sign an RFC822 message and return the DKIM-Signature header line.
 
@@ -327,10 +343,12 @@ def sign(message, selector, domain, privkey, identity=None, canonicalize=(Simple
         raise KeyFormatError("Private key not found")
     try:
         pkdata = base64.b64decode(m.group(1))
-    except TypeError, e:
+        pkdata = force_cfromb(pkdata)
+
+    except TypeError as e:
         raise KeyFormatError(str(e))
     if debuglog is not None:
-        print >>debuglog, " ".join("%02x" % ord(x) for x in pkdata)
+        print(" ".join("%02x" % ord(x) for x in pkdata), file=debuglog)
     pka = asn1_parse(ASN1_RSAPrivateKey, pkdata)
     pk = {
         'version': pka[0][0],
@@ -358,15 +376,16 @@ def sign(message, selector, domain, privkey, identity=None, canonicalize=(Simple
     body = canonicalize[1].canonicalize_body(body)
 
     h = hashlib.sha256()
-    h.update(body)
+    h.update(force_bString(body))
     bodyhash = base64.b64encode(h.digest())
+    bodyhash = force_cfromb(bodyhash)
 
     sigfields = [x for x in [
         ('v', "1"),
         ('a', "rsa-sha256"),
         ('c', "%s/%s" % (canonicalize[0].name, canonicalize[1].name)),
         ('d', domain),
-        ('i', identity or "@"+domain),
+        ('i', identity or "@" + domain),
         length and ('l', len(body)),
         ('q', "dns/txt"),
         ('s', selector),
@@ -380,16 +399,21 @@ def sign(message, selector, domain, privkey, identity=None, canonicalize=(Simple
     sig = fold(sig)
 
     if debuglog is not None:
-        print >>debuglog, "sign headers:", sign_headers + [("DKIM-Signature", " "+"; ".join("%s=%s" % x for x in sigfields))]
+        print("sign headers:", sign_headers +
+              [("DKIM-Signature", " " + "; ".join("%s=%s" %
+                                                  x for x in sigfields))], file=debuglog)
     h = hashlib.sha256()
     for x in sign_headers:
-        h.update(x[0])
-        h.update(":")
-        h.update(x[1])
-    h.update(sig)
+        h.update(force_bString(x[0]))
+        h.update(b":")
+        h.update(force_bString(x[1]))
+    h.update(force_bString(sig))
     d = h.digest()
+    d = force_cfromb(d)
+
     if debuglog is not None:
-        print >>debuglog, "sign digest:", " ".join("%02x" % ord(x) for x in d)
+        print("sign digest:", " ".join("%02x" % ord(x)
+                                       for x in d), file=debuglog)
 
     dinfo = asn1_build(
         (SEQUENCE, [
@@ -401,13 +425,17 @@ def sign(message, selector, domain, privkey, identity=None, canonicalize=(Simple
         ])
     )
     modlen = len(int2str(pk['modulus']))
-    if len(dinfo)+3 > modlen:
+    if len(dinfo) + 3 > modlen:
         raise ParameterError("Hash too large for modulus")
-    sig2 = int2str(pow(str2int("\x00\x01"+"\xff"*(modlen-len(dinfo)-3)+"\x00"+dinfo), pk['privateExponent'], pk['modulus']), modlen)
-    sig += base64.b64encode(''.join(sig2))
+    signature = "\x00\x01" + "\xff" * (modlen - len(dinfo) - 3) +"\x00" + dinfo
+    sig2 = int2str(pow(str2int(signature), pk['privateExponent'], pk['modulus']), modlen)
+    sigEncoded = base64.b64encode(force_bfromc(''.join(sig2)))
+    sigEncoded = force_cfromb(sigEncoded)
+    sig += sigEncoded
 
     return sig + "\r\n"
 
+
 def verify(message, debuglog=None):
     """Verify a DKIM signature on an RFC822 formatted message.
 
@@ -426,89 +454,98 @@ def verify(message, debuglog=None):
 
     a = re.split(r"\s*;\s*", sigheaders[0][1].strip())
     if debuglog is not None:
-        print >>debuglog, "a:", a
+        print("a:", a, file=debuglog)
     sig = {}
     for x in a:
         if x:
             m = re.match(r"(\w+)\s*=\s*(.*)", x, re.DOTALL)
             if m is None:
                 if debuglog is not None:
-                    print >>debuglog, "invalid format of signature part: %s" % x
+                    print("invalid format of signature part: %s" %
+                          x, file=debuglog)
                 return False
             sig[m.group(1)] = m.group(2)
     if debuglog is not None:
-        print >>debuglog, "sig:", sig
+        print("sig:", sig, file=debuglog)
 
     if 'v' not in sig:
         if debuglog is not None:
-            print >>debuglog, "signature missing v="
+            print("signature missing v=", file=debuglog)
         return False
     if sig['v'] != "1":
         if debuglog is not None:
-            print >>debuglog, "v= value is not 1 (%s)" % sig['v']
+            print("v= value is not 1 (%s)" % sig['v'], file=debuglog)
         return False
     if 'a' not in sig:
         if debuglog is not None:
-            print >>debuglog, "signature missing a="
+            print("signature missing a=", file=debuglog)
         return False
     if 'b' not in sig:
         if debuglog is not None:
-            print >>debuglog, "signature missing b="
+            print("signature missing b=", file=debuglog)
         return False
     if re.match(r"[\s0-9A-Za-z+/]+=*$", sig['b']) is None:
         if debuglog is not None:
-            print >>debuglog, "b= value is not valid base64 (%s)" % sig['b']
+            print("b= value is not valid base64 (%s)" %
+                  sig['b'], file=debuglog)
         return False
     if 'bh' not in sig:
         if debuglog is not None:
-            print >>debuglog, "signature missing bh="
+            print("signature missing bh=", file=debuglog)
         return False
     if re.match(r"[\s0-9A-Za-z+/]+=*$", sig['bh']) is None:
         if debuglog is not None:
-            print >>debuglog, "bh= value is not valid base64 (%s)" % sig['bh']
+            print("bh= value is not valid base64 (%s)" %
+                  sig['bh'], file=debuglog)
         return False
     if 'd' not in sig:
         if debuglog is not None:
-            print >>debuglog, "signature missing d="
+            print("signature missing d=", file=debuglog)
         return False
     if 'h' not in sig:
         if debuglog is not None:
-            print >>debuglog, "signature missing h="
+            print("signature missing h=", file=debuglog)
         return False
-    if 'i' in sig and (not sig['i'].endswith(sig['d']) or sig['i'][-len(sig['d'])-1] not in "@."):
+    if 'i' in sig and (not sig['i'].endswith(sig['d']) or sig['i'][-len(sig['d']) - 1] not in "@."):
         if debuglog is not None:
-            print >>debuglog, "i= domain is not a subdomain of d= (i=%s d=%d)" % (sig['i'], sig['d'])
+            print("i= domain is not a subdomain of d= (i=%s d=%d)" % (
+                sig['i'], sig['d']), file=debuglog)
         return False
     if 'l' in sig and re.match(r"\d{,76}$", sig['l']) is None:
         if debuglog is not None:
-            print >>debuglog, "l= value is not a decimal integer (%s)" % sig['l']
+            print("l= value is not a decimal integer (%s)" % sig[
+                'l'], file=debuglog)
         return False
     if 'q' in sig and sig['q'] != "dns/txt":
         if debuglog is not None:
-            print >>debuglog, "q= value is not dns/txt (%s)" % sig['q']
+            print("q= value is not dns/txt (%s)" % sig['q'], file=debuglog)
         return False
     if 's' not in sig:
         if debuglog is not None:
-            print >>debuglog, "signature missing s="
+            print("signature missing s=", file=debuglog)
         return False
     if 't' in sig and re.match(r"\d+$", sig['t']) is None:
         if debuglog is not None:
-            print >>debuglog, "t= value is not a decimal integer (%s)" % sig['t']
+            print("t= value is not a decimal integer (%s)" % sig[
+                't'], file=debuglog)
         return False
     if 'x' in sig:
         if re.match(r"\d+$", sig['x']) is None:
             if debuglog is not None:
-                print >>debuglog, "x= value is not a decimal integer (%s)" % sig['x']
+                print("x= value is not a decimal integer (%s)" % sig[
+                    'x'], file=debuglog)
             return False
         if int(sig['x']) < int(sig['t']):
             if debuglog is not None:
-                print >>debuglog, "x= value is less than t= value (x=%s t=%s)" % (sig['x'], sig['t'])
+                print("x= value is less than t= value (x=%s t=%s)" % (
+                    sig['x'], sig['t']), file=debuglog)
             return False
 
     m = re.match("(\w+)(?:/(\w+))?$", sig['c'])
     if m is None:
         if debuglog is not None:
-            print >>debuglog, "c= value is not in format method/method (%s)" % sig['c']
+            print("c= value is not in format method/method (%s)" % sig[
+                'c'], file=debuglog)
         return False
     can_headers = m.group(1)
     if m.group(2) is not None:
@@ -522,7 +559,8 @@ def verify(message, debuglog=None):
         canonicalize_headers = Relaxed
     else:
         if debuglog is not None:
-            print >>debuglog, "Unknown header canonicalization (%s)" % can_headers
+            print("Unknown header canonicalization (%s)" %
+                  can_headers, file=debuglog)
         return False
 
     headers = canonicalize_headers.canonicalize_headers(headers)
@@ -533,7 +571,8 @@ def verify(message, debuglog=None):
         body = Relaxed.canonicalize_body(body)
     else:
         if debuglog is not None:
-            print >>debuglog, "Unknown body canonicalization (%s)" % can_body
+            print("Unknown body canonicalization (%s)" %
+                  can_body, file=debuglog)
         return False
 
     if sig['a'] == "rsa-sha1":
@@ -544,23 +583,24 @@ def verify(message, debuglog=None):
         hashid = HASHID_SHA256
     else:
         if debuglog is not None:
-            print >>debuglog, "Unknown signature algorithm (%s)" % sig['a']
+            print("Unknown signature algorithm (%s)" % sig['a'], file=debuglog)
         return False
 
     if 'l' in sig:
         body = body[:int(sig['l'])]
 
     h = hasher()
-    h.update(body)
+    h.update(force_bString(body))
     bodyhash = h.digest()
     if debuglog is not None:
-        print >>debuglog, "bh:", base64.b64encode(bodyhash)
+        print("bh:", base64.b64encode(bodyhash), file=debuglog)
     if bodyhash != base64.b64decode(re.sub(r"\s+", "", sig['bh'])):
         if debuglog is not None:
-            print >>debuglog, "body hash mismatch (got %s, expected %s)" % (base64.b64encode(bodyhash), sig['bh'])
+            print("body hash mismatch (got %s, expected %s)" % (
+                base64.b64encode(bodyhash), sig['bh']), file=debuglog)
         return False
 
-    s = dnstxt(sig['s']+"._domainkey."+sig['d']+".")
+    s = dnstxt(sig['s'] + "._domainkey." + sig['d'] + ".")
     if not s:
         return False
     a = re.split(r"\s*;\s*", s)
@@ -571,9 +611,12 @@ def verify(message, debuglog=None):
             pub[m.group(1)] = m.group(2)
         else:
             if debuglog is not None:
-                print >>debuglog, "invalid format in _domainkey txt record"
+                print("invalid format in _domainkey txt record", file=debuglog)
             return False
-    x = asn1_parse(ASN1_Object, base64.b64decode(pub['p']))
+    pkey = base64.b64decode(pub['p'])
+    pkey = force_cfromb(pkey)
+
+    x = asn1_parse(ASN1_Object, pkey)
     # Not sure why the [1:] is necessary to skip a byte.
     pkd = asn1_parse(ASN1_RSAPublicKey, x[0][1][1:])
     pk = {
@@ -582,11 +625,11 @@ def verify(message, debuglog=None):
     }
     modlen = len(int2str(pk['modulus']))
     if debuglog is not None:
-        print >>debuglog, "modlen:", modlen
+        print("modlen:", modlen, file=debuglog)
 
     include_headers = re.split(r"\s*:\s*", sig['h'])
     if debuglog is not None:
-        print >>debuglog, "include_headers:", include_headers
+        print("include_headers:", include_headers, file=debuglog)
     sign_headers = []
     lastindex = {}
     for h in include_headers:
@@ -597,19 +640,25 @@ def verify(message, debuglog=None):
                 sign_headers.append(headers[i])
                 break
         lastindex[h] = i
-    # The call to _remove() assumes that the signature b= only appears once in the signature header
-    sign_headers += [(x[0], x[1].rstrip()) for x in canonicalize_headers.canonicalize_headers([(sigheaders[0][0], _remove(sigheaders[0][1], sig['b']))])]
+    # The call to _remove() assumes that the signature b= only appears once in
+    # the signature header
+    sign_headers += [(x[0], x[1].rstrip()) for x in canonicalize_headers.canonicalize_headers(
+        [(sigheaders[0][0], _remove(sigheaders[0][1], sig['b']))])]
     if debuglog is not None:
-        print >>debuglog, "verify headers:", sign_headers
+        print("verify headers:", sign_headers, file=debuglog)
 
     h = hasher()
     for x in sign_headers:
-        h.update(x[0])
-        h.update(":")
-        h.update(x[1])
+        h.update(force_bString(x[0]))
+        h.update(force_bString(":"))
+        h.update(force_bString(x[1]))
     d = h.digest()
+    d = force_cfromb(d)
+
     if debuglog is not None:
-        print >>debuglog, "verify digest:", " ".join("%02x" % ord(x) for x in d)
+        print("verify digest:", " ".join(
+            "%02x" % ord(x) for x in d), file=debuglog)
+
 
     dinfo = asn1_build(
         (SEQUENCE, [
@@ -621,27 +670,37 @@ def verify(message, debuglog=None):
         ])
     )
     if debuglog is not None:
-        print >>debuglog, "dinfo:", " ".join("%02x" % ord(x) for x in dinfo)
-    if len(dinfo)+3 > modlen:
+        print("dinfo:", " ".join("%02x" % ord(x)
+                                 for x in dinfo), file=debuglog)
+    if len(dinfo) + 3 > modlen:
         if debuglog is not None:
-            print >>debuglog, "Hash too large for modulus"
+            print("Hash too large for modulus", file=debuglog)
         return False
-    sig2 = "\x00\x01"+"\xff"*(modlen-len(dinfo)-3)+"\x00"+dinfo
+    sig2 = "\x00\x01" + "\xff" * (modlen - len(dinfo) - 3) + "\x00" + dinfo
+    sig2 = force_cfromb(sig2)
     if debuglog is not None:
-        print >>debuglog, "sig2:", " ".join("%02x" % ord(x) for x in sig2)
-        print >>debuglog, sig['b']
-        print >>debuglog, re.sub(r"\s+", "", sig['b'])
-    v = int2str(pow(str2int(base64.b64decode(re.sub(r"\s+", "", sig['b']))), pk['publicExponent'], pk['modulus']), modlen)
+        print("sig2:", " ".join("%02x" % ord(x) for x in sig2), file=debuglog)
+        print(sig['b'], file=debuglog)
+        print(re.sub(r"\s+", "", sig['b']), file=debuglog)
+
+
+    sigEncoded = base64.b64decode(force_bfromc(re.sub(r"\s+", "", sig['b'])))
+    sigEncoded = force_cfromb((sigEncoded))
+
+    v = int2str(pow(str2int(sigEncoded), pk['publicExponent'], pk['modulus']), modlen)
+
     if debuglog is not None:
-        print >>debuglog, "v:", " ".join("%02x" % ord(x) for x in v)
+        print("v:", " ".join("%02x" % ord(x) for x in v), file=debuglog)
     assert len(v) == len(sig2)
     # Byte-by-byte compare of signatures
     return not [1 for x in zip(v, sig2) if x[0] != x[1]]
 
 if __name__ == "__main__":
-    message = """From: greg@hewgill.com\r\nSubject: test\r\n message\r\n\r\nHi.\r\n\r\nWe lost the game. Are you hungry yet?\r\n\r\nJoe.\r\n"""
-    print rfc822_parse(message)
-    sig = sign(message, "greg", "hewgill.com", open("/home/greg/.domainkeys/rsa.private").read())
-    print sig
-    print verify(sig+message)
-    #print sign(open("/home/greg/tmp/message").read(), "greg", "hewgill.com", open("/home/greg/.domainkeys/rsa.private").read())
\ No newline at end of file
+    msg = """From: greg@hewgill.com\r\nSubject: test\r\n message\r\n\r\nHi.\r\n\r\nWe lost the game. Are you hungry yet?\r\n\r\nJoe.\r\n"""
+    print(rfc822_parse(msg))
+    sign = sign(msg, "greg", "hewgill.com", open(
+        "/home/greg/.domainkeys/rsa.private").read())
+    print(sign)
+    print(verify(sign + msg))
+    # print sign(open("/home/greg/tmp/message").read(), "greg", "hewgill.com",
+    # open("/home/greg/.domainkeys/rsa.private").read())
