@@ -22,6 +22,9 @@ import logging
 import weakref
 import hashlib
 import base64
+import re
+import string
+import random
 import typing as tp
 from typing import Optional
 from fuglu.extensions.filearchives import Archivehandle
@@ -56,7 +59,7 @@ ATTPARSEERROR_CONTENTTYPE= "application/unknown"
 class NoExtractInfo(object):
     """Store info about files """
 
-    valid_causes = [u"level", u"archivehandle", u"toolarge", u"extractsize", u'numfiles']
+    valid_causes = ["level", "archivehandle", "toolarge", "extractsize", 'numfiles']
 
     def __init__(self):
         """Constructor"""
@@ -298,10 +301,10 @@ class Mailattachment(Cachelimits):
         """
 
         # only for first level attachments
-        decoded_buffer = u""
+        decoded_buffer = ""
         if self.in_obj is None:
             charset = self.content_charset_mime if self.content_charset_mime else "utf-8"
-            decoded_buffer = force_uString(self.buffer, encodingGuess=charset)
+            decoded_buffer = force_uString(self.buffer, encodingGuess=charset, errors='strict+ignore')
 
         return decoded_buffer
 
@@ -688,14 +691,14 @@ class Mailattachment(Cachelimits):
                     filesize = self.archive_handle.filesize(fname)
                 except Exception as e:
                     if noextractinfo is not None:
-                        noextractinfo.append(fname, u"archivehandle", u"exception: %s" % force_uString(e))
+                        noextractinfo.append(fname, "archivehandle", "exception: %s" % force_uString(e))
                     return None
 
                 try:
                     buffer = self.archive_handle.extract(fname,maxsize_extract)
                 except Exception as e:
                     if noextractinfo is not None:
-                        noextractinfo.append(fname, u"archivehandle", u"exception: %s" % force_uString(e))
+                        noextractinfo.append(fname, "archivehandle", "exception: %s" % force_uString(e))
                     return None
 
                 if buffer is None:
@@ -703,10 +706,9 @@ class Mailattachment(Cachelimits):
                         if maxsize_extract is not None \
                                 and filesize is not None \
                                 and filesize > maxsize_extract:
-                            noextractinfo.append(fname, u"extractsize", u"not extracted: %u > %u"
-                                                  % (filesize, maxsize_extract))
+                            noextractinfo.append(fname, "extractsize", "not extracted: %u > %u" % (filesize, maxsize_extract))
                         else:
-                            noextractinfo.append(fname, u"archivehandle", u"(no info)")
+                            noextractinfo.append(fname, "archivehandle", "(no info)")
                     return None
                 obj = Mailattachment(buffer, fname, self._mgr() if self._mgr else None, self.fugluid, filesize=filesize, in_obj=self,
                                      is_attachment=self.is_attachment, is_inline=self.is_inline)
@@ -779,9 +781,9 @@ class Mailattachment(Cachelimits):
             try:
                 handle = Archivehandle(self.archive_type, BytesIO(self.buffer),archivename=self.filename)
             except Exception as e:
-                self.logger.error("%s, Problem creating Archivehandle for file: "
-                                  "%s using archive handler %s (message: %s) -> ignore"
-                                  % (self.fugluid, self.filename, str(self.archive_type), force_uString(e)))
+                self.logger.warning(f"{self.fugluid}, Problem creating Archivehandle for file: "
+                                    f"{self.filename} using archive handler {str(self.archive_type)} "
+                                    f"(message: {force_uString(e)}) -> ignore")
                 if force_uString(e).strip() == "":
                     # store class name if no string
                     self._archive_handle_exc = e.__class__.__name__
@@ -838,13 +840,29 @@ class Mailattachment(Cachelimits):
     
     def location(self):
         """Print the location of the the file in the archive tree"""
-        element_of = u" \u2208 "
+        element_of = " \u2208 "
         location = self.filename
         if self.parent_archives:
-            location += element_of + element_of.join([u"{" + obj().filename + u"}" for obj in self.parent_archives])
+            location += element_of + element_of.join(["{" + obj().filename + "}" for obj in self.parent_archives])
         return location
     
     
+    def get_mangled_filename(self, prefix='', maxchars=15):
+        first=self.filename.split('.')[0]
+        #replace spaces with underscore
+        first = re.sub('\s', '_', first)
+        #remove all non alnum chars
+        first=''.join([x for x in first if x in string.ascii_letters or x in string.digits])
+        if first.strip()=='' or first.strip()=='filename': #renattach renames to 'filename'
+            first='upn-%s' % random.randint(1000,9999)
+        elif len(first) < 4:
+            first = 'sh-%s-%s' % (random.randint(1000,9999), first)
+        #strip to a machimum of maxchars characters
+        first=first[:maxchars]
+        newfilename = '%s.%s' % (prefix, first)
+        return newfilename
+    
+    
     def __str__(self):
         """
         String conversion function for object. Creates
@@ -853,15 +871,15 @@ class Mailattachment(Cachelimits):
             (str): string with object information
 
         """
-        element_of = u" \u2208 "
-        return u"""
+        element_of = " \u2208 "
+        return """
 Filename     : %s        
 Size (bytes) : %s    
 Location     : %s        
 Archive type : %s        
-Content type : %s""" % (self.filename,u'(unknown)' if self.filesize is None else str(self.filesize),
+Content type : %s""" % (self.filename,'(unknown)' if self.filesize is None else str(self.filesize),
                         self.filename + element_of +
-                        element_of.join([u"{" + obj().filename +u"}" for obj in self.parent_archives]),
+                        element_of.join(["{" + obj().filename +"}" for obj in self.parent_archives]),
                         self.archive_type,
                         self.contenttype)
 
