@@ -706,7 +706,7 @@ Note: The first rule to match in a message is the only rule that will be applied
 
         self.requiredvars = {
             'archiverules': {
-                'default': '/etc/fuglu/archive.regex',
+                'default': '${confdir}/archive.regex',
                 'description': 'Archiving SuspectFilter File',
             },
             'archivebackends': {
