@@ -258,7 +258,7 @@ Actions: This plugin will delete messages if they contain blocked attachments.
 Prerequisites: You must have the python ``file`` or ``magic`` module installed. Additionaly, for scanning filenames within rar archives, fuglu needs the python ``rarfile`` module.
 
 
-The attachment configuration files are in ``/etc/fuglu/rules``. You should have two default files there: ``default-filenames.conf`` which defines what filenames are allowed and ``default-filetypes.conf`` which defines what content types a attachment may have.
+The attachment configuration files are in ``${confdir}/rules``. You should have two default files there: ``default-filenames.conf`` which defines what filenames are allowed and ``default-filetypes.conf`` which defines what content types a attachment may have.
 
 For domain rules, create a new file ``<domainname>-filenames.conf`` / ``<domainname>-filetypes.conf`` , eg. ``fuglu.org-filenames.conf`` / ``fuglu.org-filetypes.conf``
 
@@ -339,7 +339,7 @@ The default query assumes the following schema:
 
 *prio*: order in which the rules are run
 
-The bounce template (eg ``/etc/fuglu/templates/blockedfile.tmpl`` ) should
+The bounce template (eg ``${confdir}/templates/blockedfile.tmpl`` ) should
 start by defining the headers, followed by a blank line, then the message body for your bounce message. Something like this:
 
 ::
@@ -364,7 +364,7 @@ The other common template variables are available as well.
         ScannerPlugin.__init__(self, config, section)
         self.requiredvars = {
             'template_blockedfile': {
-                'default': '/etc/fuglu/templates/blockedfile.tmpl',
+                'default': '${confdir}/templates/blockedfile.tmpl',
                 'description': 'Mail template for the bounce to inform sender about blocked attachment',
             },
 
@@ -374,7 +374,7 @@ The other common template variables are available as well.
             },
 
             'rulesdir': {
-                'default': '/etc/fuglu/rules',
+                'default': '${confdir}/rules',
                 'description': 'directory that contains attachment rules',
             },
 
@@ -880,8 +880,8 @@ class AttHashAction(ScannerPlugin):
         self.logger = self._logger()
         self.rbllookup = None
         self.requiredvars = {
-            'blacklistconfig':{
-                'default':'/etc/fuglu/atthash-rbl.conf',
+            'blocklistconfig':{
+                'default':'${confdir}/atthash-rbl.conf',
                 'description':'Domainmagic RBL lookup config file',
             },
             'enginename': {
@@ -897,10 +897,10 @@ class AttHashAction(ScannerPlugin):
     
     def _init_rbllookup(self):
         if self.rbllookup is None:
-            blacklistconfig = self.config.get(self.section,'blacklistconfig')
-            if os.path.exists(blacklistconfig):
+            blocklistconfig = self.config.get(self.section,'blocklistconfig')
+            if os.path.exists(blocklistconfig):
                 self.rbllookup = RBLLookup()
-                self.rbllookup.from_config(blacklistconfig)
+                self.rbllookup.from_config(blocklistconfig)
                 
                 
     def _check_hash(self, myhash):
@@ -928,7 +928,7 @@ class AttHashAction(ScannerPlugin):
             return DUNNO
         self._init_rbllookup()
         if self.rbllookup is None:
-            self.logger.error('Not scanning - blacklistconfig could not be loaded')
+            self.logger.error('Not scanning - blocklistconfig could not be loaded')
             return DUNNO
         
         for attobj in suspect.att_mgr.get_objectlist(level=0):
@@ -984,16 +984,16 @@ class FileHashCheck(ScannerPlugin):
                 'description': 'the hashing algorithm to be used',
             },
             'extensionsfile': {
-                'default': '/etc/fuglu/conf.d/filehash_extensions.txt',
+                'default': '${confdir}/conf.d/filehash_extensions.txt',
                 'description': 'path to file containing accepted file extensions. One per line, comments start after #',
             },
             'hashskiplistfile': {
-                'default': '/etc/fuglu/conf.d/filehash_skiphash.txt',
-                'description': 'path to file containing blacklisted hashes. One hash per line, comments start after #',
+                'default': '${confdir}/conf.d/filehash_skiphash.txt',
+                'description': 'path to file containing skiplisted hashes. One hash per line, comments start after #',
             },
             'filenameskipfile': {
-                'default': '/etc/fuglu/conf.d/filehash_skipfilename.txt',
-                'description': 'path to file containing blacklisted file name content. One per line, comments start after #',
+                'default': '${confdir}/conf.d/filehash_skipfilename.txt',
+                'description': 'path to file containing file name fragments of file names to be skipped. One per line, comments start after #',
             },
             'allowmissingextension': {
                 'default': 'False',
@@ -1160,7 +1160,7 @@ class FileHashCheck(ScannerPlugin):
             print('ERROR: invalid hash type %s' % hashtype)
             success = False
         
-        self.hashskiplist = FileList(filename=self.config.get(self.section, 'hashblacklistfile'), lowercase=True,
+        self.hashskiplist = FileList(filename=self.config.get(self.section, 'hashskiplistfile'), lowercase=True,
                                      additional_filters=[FileList.inline_comments_filter])
         if self.hashskiplist.get_list():
             print('WARNING: empty hash skiplist')
@@ -1174,7 +1174,7 @@ class FileHashCheck(ScannerPlugin):
         else:
             print('INFO: checking %s extensions' % len(ext))
         
-        self.filenameskip = FileList(filename=self.config.get(self.section, 'bannedfilenamecontentfile'),
+        self.filenameskip = FileList(filename=self.config.get(self.section, 'filenameskipfile'),
                                      lowercase=True, additional_filters=[FileList.inline_comments_filter])
         if len(self.filenameskip.get_list()) == 0:
             success = False
@@ -1416,7 +1416,7 @@ class FileHashFeeder(FileHashCheck):
     def _init_kafka(self):
         if self.kafkaproducer is not None:
             return
-        self.bootstrap_servers = self.config.get(self.section, 'kafkahosts').split()
+        self.bootstrap_servers = self.config.getlist(self.section, 'kafkahosts')
         if self.bootstrap_servers:
             self.kafkatopic = self.config.get(self.section, 'kafkatopic')
             timeout = self.config.getint(self.section, 'timeout')
