@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from fuglu.shared import AVScannerPlugin, string_to_actioncode, DUNNO, actioncode_to_string
+from fuglu.shared import AVScannerPlugin, string_to_actioncode, DUNNO, actioncode_to_string, FileList
 from fuglu.stringencode import force_bString, force_uString
 from fuglu.protocolbase import set_keepalive_linux
 import socket
@@ -30,6 +30,10 @@ threadLocal = threading.local()
 MAX_SCANS_PER_SOCKET = 5000
 
 
+class ClamavTimeout(Exception):
+    pass
+
+
 class ClamavPlugin(AVScannerPlugin):
 
     """This plugin passes suspects to a clam daemon. 
@@ -83,6 +87,11 @@ Tags:
                 'default': 'DEFAULTVIRUSACTION',
                 'description': "action if infection is detected (DUNNO, REJECT, DELETE)",
             },
+            
+            'virusaction_unofficial': {
+                'default': '',
+                'description': "action if infection is detected by UNOFFICIAL (3rd party) signature (DUNNO, REJECT, DELETE). if left empty use standard virusaction",
+            },
 
             'problemaction': {
                 'default': 'DEFER',
@@ -108,15 +117,49 @@ Tags:
                 'default': '30',
                 'description': "process timeout",
             },
+            
             'skip_on_previous_virus': {
                 'default': 'none',
                 'description': 'define AVScanner engine names causing current plugin to skip if they found already a virus',
             },
+            
+            'skiplist_file': {
+                'default': '',
+                'description': 'path to file with signature names that can be skipped if message is welcomelisted. list one signature per line, signature is case sensitive',
+            },
+            
+            'enginename': {
+                'default': '',
+                'description': 'set custom engine name (defaults to %s)' % self.enginename,
+            },
         }
         self.logger = self._logger()
         self.enginename = 'ClamAV'
+        self.skiplist = None
     
     
+    def _init_skiplist(self):
+        if self.skiplist is None:
+            skiplist_file = self.config.get(self.section, 'skiplist_file')
+            if skiplist_file:
+                self.skiplist = FileList(skiplist_file)
+    
+    def _check_skiplist(self, suspect, viruses):
+        """
+        if message is welcomelisted, skip defined signature hits
+        :param suspect: the suspect object
+        :param viruses: dict of virus scan results
+        :return: (bool) True if hit should not be counted
+        """
+        self._init_skiplist()
+        if self.skiplist and suspect.is_welcomelisted():
+            skiplist = self.skiplist.get_list()
+            virusnames = viruses.keys()
+            if len(virusnames) == 1 and virusnames[0] in skiplist:
+                self.logger.info('%s got hit on %s but is skiplisted' % (suspect.id, ','.join(virusnames)))
+                return True
+        return False
+    
     def __str__(self):
         return "Clam AV"
 
@@ -128,40 +171,69 @@ Tags:
         if skip:
             self.logger.info("%s %s" % (suspect.id, skip))
             return DUNNO
-
+        
+        viruses = {}
+        success = False
         content = suspect.get_source()
 
-        for i in range(0, self.config.getint(self.section, 'retries')):
+        attempts = max_attempts = max(self.config.getint(self.section, 'retries'), 1)
+        #for i in range(0, self.config.getint(self.section, 'retries')):
+        while attempts:
+            attempts -= 1
             try:
                 viruses = self.scan_stream(content, suspect.id)
-                actioncode, message = self._virusreport(suspect, viruses)
-                return actioncode, message
+                success = True
+                break
             except socket.error as e:
                 self.__invalidate_socket()
 
-                # don't warn the first time if it's just a broken pipe which
+                # don't warn the first times if it's just a broken pipe which
                 # can happen with the new pipelining protocol
-                if not (i == 0 and e.errno == errno.EPIPE):
-                    self.logger.warning("%s Error encountered while contacting clamd (try %s of %s): %s" % (
-                        suspect.id, i + 1, self.config.getint(self.section, 'retries'), str(e)))
+                msg = f"{suspect.id} Problem encountered while contacting clamd " \
+                      f"(try {max_attempts - attempts}/{max_attempts}): {str(e)}"
+                if attempts:
+                    if not e.errno == errno.EPIPE:
+                        self.logger.warning(msg)
                 else:
-                    self.logger.exception(e)
+                    self.logger.error(msg, exc_info=e)
+            except ClamavTimeout as e:
+                msg = f"Clamav timeout raised (try {max_attempts - attempts}/{max_attempts}): {str(e)}"
+                self.logger.warning(msg) if attempts else self.logger.error(msg)
+                self.__invalidate_socket()
             except Exception as e:
                 self.logger.exception(e)
                 self.__invalidate_socket()
 
-        self.logger.error("%s Clamdscan failed after %s retries" %
-                          (suspect.id, self.config.getint(self.section, 'retries')))
-        
-        if self.config.getboolean(self.section, 'clamscanfallback'):
+        if not success:
+            self.logger.error(f"{suspect.id} Clamdscan failed after {max_attempts} retries")
+
+        if not success and self.config.getboolean(self.section, 'clamscanfallback'):
             try:
                 viruses = self.scan_shell(content)
-                actioncode, message = self._virusreport(suspect, viruses)
-                return actioncode, message
+                success = True
             except Exception:
                 self.logger.error('%s failed to scan using fallback clamscan' % suspect.id)
+
+        if not success:
+            return self._problemcode()
+        elif self._check_skiplist(suspect, viruses):
+            return DUNNO
+        else:
+            actioncode, message = self._virusreport(suspect, viruses)
+            if viruses and self.config.get(self.section, 'virusaction_unofficial'):
+                actioncode = self._virusaction_unofficial(viruses, actioncode)
+            return actioncode, message
+    
         
-        return self._problemcode()
+    def _virusaction_unofficial(self, viruses, actioncode):
+        # override virusaction if one of the virus hits is caused by "UNOFFICIAL" signature
+        for filename in viruses:
+            signame = viruses[filename]
+            if signame.endswith('.UNOFFICIAL'):
+                virusaction = self.config.get(self.section, 'virusaction_unofficial')
+                actioncode = string_to_actioncode(virusaction, self.config)
+                break
+        return actioncode
     
     
     def scan_shell(self, content):
@@ -244,8 +316,7 @@ Tags:
         self.logger.debug('%s: got result' % suspectid)
 
         if result.startswith('INSTREAM size limit exceeded'):
-            raise Exception(
-                "%s: Clamd size limit exeeded. Make sure fuglu's clamd maxsize config is not larger than clamd's StreamMaxLength" % suspectid)
+            raise Exception("%s: Clamd size limit exeeded. Make sure fuglu's clamd maxsize config is not larger than clamd's StreamMaxLength" % suspectid)
         if result.startswith('UNKNOWN'):
             raise Exception("%s: Clamd doesn't understand INSTREAM command. very old version?" % suspectid)
 
@@ -306,7 +377,7 @@ Tags:
                     # swarm setup with multiple clam services during an update
                     runtime = time.time() - starttime
                     if runtime > readtimeout:
-                        raise Exception(f"{suspectID}: 0-chunk-length read timeout after {runtime:.2f}s")
+                        raise ClamavTimeout(f"{suspectID}: 0-chunk-length read timeout after {runtime:.2f}s")
                     continue
                 data += chunk
                 if chunk.endswith(b'\0'):
@@ -325,7 +396,7 @@ Tags:
                 failedAttempt += 1
                 self.logger.warning("%s: Failed receive attempt %u/%u: %s" % (suspectID,failedAttempt, maxFailedAttempts, str(e)))
                 if failedAttempt == maxFailedAttempts:
-                    raise
+                    raise ClamavTimeout(f"{suspectID}, Max failed received attempts({maxFailedAttempts}): {str(e)}")
             else:
                 # Sometimes we get one socket error and after that we never get a proper answer to satisfy
                 # break or exception condition in try block, neither are there subsequent socket errors.
@@ -334,7 +405,7 @@ Tags:
                 # loop termination condition.
                 runtime = time.time() - starttime
                 if runtime > readtimeout:
-                    raise Exception(f"{suspectID}: Read timeout after {runtime:.2f}s")
+                    raise ClamavTimeout(f"{suspectID}: Read timeout after {runtime:.2f}s > {readtimeout:.2f}s")
 
         return data[:-1]  # remove \0 at the end
     
