@@ -386,7 +386,7 @@ class URIWriter(ScannerPlugin):
             },
             
             'urltype_map_file': {
-                'default': '/etc/fuglu/uriwriter_urltypes.txt',
+                'default': '${confdir}/uriwriter_urltypes.txt',
                 'description': 'maps rcpt user name to url type categories'
             },
             
