@@ -38,7 +38,7 @@ import fuglu.connectors.asyncmilterconnector as asm
 import fuglu.connectors.milterconnector as sm
 
 from fuglu.shared import ScannerPlugin, apply_template, DUNNO, FileList, string_to_actioncode, get_default_cache, \
-    extract_domain, Suspect, Cache, _SuspectTemplate, actioncode_to_string
+    extract_domain, Suspect, Cache, _SuspectTemplate, actioncode_to_string, deprecated
 from fuglu.mshared import BMPRCPTMixin, BasicMilterPlugin, EOM, retcode2milter
 from fuglu.extensions.sql import get_session, SQL_EXTENSION_ENABLED, get_domain_setting
 from fuglu.extensions.dnsquery import DNSQUERY_EXTENSION_ENABLED, lookup, QTYPE_TXT, QTYPE_MX
@@ -123,7 +123,7 @@ def extract_from_domains(suspect, header='From', get_display_part=False):
     from_doms = []
     for item in from_addresses:
         if get_display_part:
-            domain_match = re.search("(?<=@)[\w.-]+", item[0])
+            domain_match = re.search("(?<=(@|＠))[\w.-]+", item[0])
             if domain_match is None:
                 continue
             from_doms.append(domain_match.group())
@@ -377,7 +377,7 @@ If fuglu handles both incoming and outgoing mails you should make sure that this
         self.requiredvars = {
             'privatekeyfile': {
                 'description': "Location of the private key file. supports standard template variables plus additional ${header_from_domain} which extracts the domain name from the From: -Header",
-                'default': "/etc/fuglu/dkim/${header_from_domain}.key",
+                'default': "${confdir}/dkim/${header_from_domain}.key",
             },
 
             'canonicalizeheaders': {
@@ -700,6 +700,7 @@ class SPFPlugin(BMPRCPTMixin, ScannerPlugin, BasicMilterPlugin):
             dbconnection = self.config.get(self.section, 'dbconnection').strip()
             sqlquery = self.config.get(self.section, 'domain_sql_query')
 
+            # use DBConfig instead of get_domain_setting
             if dbconnection != '' and SQL_EXTENSION_ENABLED:
                 cache = get_default_cache()
                 if get_domain_setting(from_domain, dbconnection, sqlquery, cache, self.section, False, self.logger):
@@ -734,7 +735,6 @@ class SPFPlugin(BMPRCPTMixin, ScannerPlugin, BasicMilterPlugin):
             ip_whitelist_file = ''
 
         if ip_whitelist_file != '' and os.path.exists(ip_whitelist_file):
-            plainlist = []
             if self.ip_whitelist_loader is None:
                 self.ip_whitelist_loader = FileList(ip_whitelist_file, lowercase=True)
 
@@ -1317,7 +1317,7 @@ class DMARCPlugin(ScannerPlugin):
             dispo = r.disposition
         except dmarc.RecordSyntaxError as e:
             self.logger.info('%s invalid DMARC record: %s' % (suspectid, str(e)))
-        except ValueError as e:
+        except ValueError:
             if aspf is not None:
                 dbgaspf = '%s;%s' % (aspf.domain, aspf.result)
             else:
@@ -1414,7 +1414,7 @@ class DomainAuthPlugin(ScannerPlugin):
         self.requiredvars = {
             'domainsfile': {
                 'description': "File containing a list of domains (one per line) which must be DKIM and/or SPF authenticated",
-                'default': "/etc/fuglu/auth_required_domains.txt",
+                'default': "${confdir}/auth_required_domains.txt",
             },
             'failaction': {
                 'default': 'DUNNO',
@@ -1496,7 +1496,7 @@ class SpearPhishPlugin(ScannerPlugin):
 
         self.requiredvars = {
             'domainsfile': {
-                'default': '/etc/fuglu/spearphish-domains',
+                'default': '${confdir}/spearphish-domains',
                 'description': 'Filename where we load spearphish domains from. One domain per line. If this setting is empty, the check will be applied to all domains.',
             },
             'virusenginename': {
@@ -1533,6 +1533,8 @@ class SpearPhishPlugin(ScannerPlugin):
             },
         }
 
+    # this looks like a duplicate of get_domain_setting from extensions.sql
+    @deprecated
     def get_domain_setting(self, domain, dbconnection, sqlquery, cache, cachename, default_value=None, logger=None):
         if logger is None:
             logger = logging.getLogger()
@@ -1583,6 +1585,7 @@ class SpearPhishPlugin(ScannerPlugin):
         dbconnection = self.config.get(self.section, 'dbconnection').strip()
         sqlquery = self.config.get(self.section, 'domain_sql_query')
         do_check = False
+        # use DBConfig instead of get_domain_setting
         if dbconnection != '':
             cache = get_default_cache()
             cachename = self.section
