@@ -128,7 +128,7 @@ class FuzorMixin(object):
         username = self.config.get(self.section, 'kafkausername')
         password = self.config.get(self.section, 'kafkapassword')
         timeout = self.config.getint(self.section, 'timeout')
-        self.backend = KafkaBackend(hosts, topic, timeout, username, password)
+        self.backend = KafkaBackend(hosts, topic, timeout, username, password, self.config)
 
 
 
@@ -647,7 +647,7 @@ class RedisBackend(FuzorBackend):
         try:
             redisconn = self.redis_pool.get_conn()
             return int(redisconn.get(digest))
-        except (ValueError, TypeError) as e:
+        except (ValueError, TypeError):
             return 0
         except (socket.timeout, redis.exceptions.TimeoutError):
             self.logger.info("Socket timeout in get")
@@ -656,9 +656,9 @@ class RedisBackend(FuzorBackend):
 
 
 class KafkaBackend(FuzorBackend):
-    def __init__(self, bootstrap_servers, topic, timeout, username, password):
+    def __init__(self, bootstrap_servers, topic, timeout, username, password, config=None):
         self.logger = logging.getLogger("fuglu.fuzor.KafkaBackend")
-        clientid = 'prod-fuglu-%s-%s' % (self.__class__.__name__, get_outgoing_helo())
+        clientid = 'prod-fuglu-%s-%s' % (self.__class__.__name__, get_outgoing_helo(config))
         self.producer = kafka.KafkaProducer(
             bootstrap_servers=bootstrap_servers, api_version=(0, 10, 1), client_id=clientid,
             request_timeout_ms=timeout*1000, sasl_plain_username=username, sasl_plain_password=password
