@@ -23,7 +23,7 @@ import asyncio
 import re
 from domainmagic.mailaddr import split_mail
 from fuglu.shared import ScannerPlugin, DUNNO, DELETE, SuspectFilter, AppenderPlugin, Suspect, get_outgoing_helo, apply_template, FileList
-from fuglu.stringencode import force_uString, force_bString
+from fuglu.stringencode import force_uString
 from fuglu.bounce import FugluSMTPClient, FugluAioSMTPClient, HAVE_AIOSMTP, SMTPException, Bounce
 from urllib.parse import urlparse
 from email.mime.multipart import MIMEMultipart
@@ -51,7 +51,7 @@ The rulefile works similar to the archive plugin. As third column you have to pr
         
         self.requiredvars = {
             'imapcopyrules': {
-                'default': '/etc/fuglu/imapcopy.regex',
+                'default': '${confdir}/imapcopy.regex',
                 'description': 'IMAP copy suspectFilter File',
             },
             
@@ -392,7 +392,7 @@ class MailFeed(AppenderPlugin):
         
         self.requiredvars = {
             'targetfile': {
-                'default': '/etc/fuglu/mailfeeds.txt',
+                'default': '${confdir}/mailfeeds.txt',
                 'description': """file with feed targets.
                 format: target.server[;opt=val;opt=val] domain1 domain2 or * for all domains
                 possible options: port=587;tls=True;xclient=True;user=user;pass=pass;from=<>;to=*;timeout=30
