@@ -368,7 +368,7 @@ class NoBounce(BMPRCPTMixin, BasicMilterPlugin):
         
         self.requiredvars = {
             'nobouncefile': {
-                'default': '/etc/fuglu/nobounce.txt',
+                'default': '${confdir}/nobounce.txt',
                 'description': 'list of domains to which bounces will be disallowed'
             },
             'rejectmessage': {
@@ -476,7 +476,7 @@ class TrapIntercept(ScannerPlugin):
         
         self.requiredvars = {
             'traps_file': {
-                'default': '/etc/fuglu/traps.txt',
+                'default': '${confdir}/traps.txt',
                 'description': 'file with known traps'
             },
             
@@ -486,7 +486,7 @@ class TrapIntercept(ScannerPlugin):
             },
             
             'sender_exceptions_file': {
-                'default': '/etc/fuglu/trap_sender_exceptions.txt',
+                'default': '${confdir}/trap_sender_exceptions.txt',
                 'description': 'file with whitelisted senders'
             },
             
