@@ -118,7 +118,7 @@ class FugluBlockWelcome(AbstractBackend):
     
     
     minimal table layout:
-    listtype, listspec, sender, host, netmask, scope
+    list_type, list_type, list_scope, sender_addr, sender_host, netmask, scope
     
     CREATE TABLE `fuglu_blwl` (
       `list_id` int(11) NOT NULL AUTO_INCREMENT,
@@ -135,23 +135,23 @@ class FugluBlockWelcome(AbstractBackend):
       KEY `idx_sort` (`list_type`, `list_scope`, `netmask`, `sender_host`, `sender_addr`)
     ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
     
-    listtype is varchar and accepts:
+    list_type is varchar and accepts:
     block (unwanted mail)
     welcome (wanted mail)
     
-    listspec is varchar and accepts:
+    list_scope is varchar and accepts:
     any (apply listing to envelope sender and header)
     env (apply to envelope sender only)
     hdr (apply to headers only)
     
-    sender is varchar and accepts:
+    sender_addr is varchar and accepts:
     null: any sender
     empty string: bounce
     %domain: any user in domain
     *.domain: any user in recursively matched domain
     user@domain: full address
     
-    host is varchar and accepts
+    sender_host is varchar and accepts
     null: any host
     ip address: full ip or first ip in cidr range
     *.hostname: recursively matching hostname
@@ -865,7 +865,7 @@ class AutoListMixin(object):
             pinginterval = self.config.getint(self.section, 'pinginterval')
             redis_pool = RedisPooledConn(redis_conn, socket_keepalive=True, socket_timeout=socket_timeout, pinginterval=pinginterval)
             maxcount = self.config.getint(self.section, 'max_count')
-            self.backend_redis = ExpiringCounter(redis_pool.pool, ttl, maxcount=maxcount)
+            self.backend_redis = ExpiringCounter(redis_pool, ttl, maxcount=maxcount)
     
     
     def _address_normalise(self, address:str):
