@@ -31,7 +31,7 @@ eg. put this in /etc/fuglu/pluginfraction.regex:
         self.filter = None
         self.requiredvars = {
             'filterfile': {
-                'default': '/etc/fuglu/pluginfraction.regex',
+                'default': '${confdir}/pluginfraction.regex',
                 'description': 'path to file containing scanner plugin fraction regex rules'
             }
         }
@@ -82,5 +82,5 @@ eg. put this in /etc/fuglu/pluginfraction.regex:
 
     def lint_filter(self):
         filterfile = self.config.get(self.section, 'filterfile')
-        filter = SuspectFilter(filterfile)
-        return filter.lint()
+        sfilter = SuspectFilter(filterfile)
+        return sfilter.lint()
