@@ -45,6 +45,9 @@ ALLSTATES = list(BasicMilterPlugin.ALL_STATES.keys()) + [EOM]
 BE_VERBOSE = False # enable for debugging
 
 
+SKIP = -100
+
+
 class TemplateFunctionWrapper(FunctionWrapperInt):
     def __init__(self, definitionstring: str, **kwargs):
         """Load a function (and keyword args) from a string"""
@@ -352,11 +355,14 @@ class Limiter(object):
         self.name = name
         self.number = None
         self.frame = None
-        self.action = string_to_actioncode(setupdict.get('action', "DUNNO").lower())
+
+        action = setupdict.get('action', "DUNNO").lower()
+        self.action = SKIP if action == "skip" else string_to_actioncode(action)
         self.bounceaction = setupdict.get('bounceaction', None)
 
         if self.bounceaction:
-            self.bounceaction = string_to_actioncode(self.bounceaction.lower())
+            bounceaction = self.bounceaction.lower()
+            self.bounceaction = SKIP if action == "skip" else string_to_actioncode(bounceaction)
         else:
             self.bounceaction = self.action
 
@@ -527,7 +533,7 @@ class RateLimitPlugin(BMPConnectMixin, BMPHeloMixin, BMPMailFromMixin,
         self.requiredvars = {
 
             'limiterfile': {
-                'default': '/etc/fuglu/ratelimit.yml',
+                'default': '${confdir}/ratelimit.yml',
                 'description': 'file based rate limits',
             },
 
@@ -688,9 +694,12 @@ class RateLimitPlugin(BMPConnectMixin, BMPHeloMixin, BMPMailFromMixin,
                     (allow, count) = await curbackend.check_allowed(eventname, limiter.number, timespan, increment)
                 else:
                     (allow, count) = curbackend.check_allowed(eventname, limiter.number, timespan, increment)
-                self.logger.debug(f'{suspect.id} {state}-Limiter event {eventname} (allow={allow},DUNNO={limiter.action == DUNNO}) count: {count}')
+                self.logger.debug(f'{suspect.id} {state}-Limiter event {eventname} (allow={allow},DUNNO={limiter.action == DUNNO}),SKIP={limiter.action == SKIP} count: {count}')
 
                 limiteraction = limiter.action if suspect.from_address else limiter.bounceaction
+                if not allow and limiteraction == SKIP:
+                    self.logger.info(f"{suspect.id} (state={state}) SKIP remaining ratelimit tests for this state")
+                    return DUNNO
                 if not allow and limiteraction != DUNNO:
                     self.logger.debug(f'{suspect.id} {state}-Limiter: instance is of type {suspect.__class__.__name__}')
                     if isinstance(suspect, Suspect):
