@@ -544,7 +544,7 @@ class AccessRestrictions(BMPConnectMixin, BMPHeloMixin, BMPMailFromMixin, BMPRCP
         super().__init__(config, section)
         self.requiredvars = {
             'restrictionfile': {
-                'default': '/etc/fuglu/accessrestrictions.yml',
+                'default': '${confdir}/accessrestrictions.yml',
                 'description': 'access restrictions yaml-file with "restrictions"-array and "setup"-dict',
             },
             'delay_rejects': {
