@@ -20,7 +20,7 @@
 # Copyright (c) 2006 Sophos Plc, www.sophos.com.
 #
 
-from fuglu.shared import AVScannerPlugin, string_to_actioncode, DEFER, DUNNO, actioncode_to_string, apply_template
+from fuglu.shared import AVScannerPlugin, string_to_actioncode, DUNNO, actioncode_to_string
 from fuglu.stringencode import force_bString, force_uString
 from fuglu.protocolbase import set_keepalive_linux
 import socket
@@ -149,7 +149,7 @@ Prerequisites: Requires a running sophos daemon with dynamic interface (SAVDI)
         if not self._accepted(s):
             raise Exception("SSSP Query rejected: %s" % self._last_line)
 
-        options = self._read_options(s)
+        self._read_options(s)
 
         # Set the options for classification
         enableoptions = [
