@@ -21,7 +21,7 @@ Vacation/Autoreply Plugin
 
 from fuglu.shared import ScannerPlugin, DUNNO
 from fuglu.bounce import Bounce
-from fuglu.extensions.sql import SQL_EXTENSION_ENABLED, get_session
+from fuglu.extensions.sql import SQL_EXTENSION_ENABLED, get_session, DeclarativeBase
 import time
 import re
 from threading import Lock
@@ -32,49 +32,51 @@ from email.mime.text import MIMEText
 from email.header import Header
 
 # from address regex
-vacation_ignoresenderregex = ["^owner-",
-                              "^request-",
-                              "-request@",
-                              # everything with 'bounce' in the lefthandside is
-                              # probably automated
-                              "bounce.*@",
-                              "-confirm@",
-                              "-errors@",
-                              "^no[\-]?reply",
-                              "^donotreply",
-                              "^postmaster@",
-                              "^mailer[-_]daemon@",
-                              "^mailer@",
-                              "^listserv@",
-                              "^majordom[o]?@",
-                              "^mailman@",
-                              "^nobody@",
-                              "^bounce",
-                              "^www(-data)?@",
-                              "^mdaemon@",
-                              "^root@",
-                              "^webmaster@",
-                              "^administrator@",
-                              "^support@",
-                              "^news(letter)?@",
-                              ]
+vacation_ignoresenderregex = [
+    "^owner-",
+    "^request-",
+    "-request@",
+    # everything with 'bounce' in the lefthandside is
+    # probably automated
+    "bounce.*@",
+    "-confirm@",
+    "-errors@",
+    "^no[\-]?reply",
+    "^donotreply",
+    "^postmaster@",
+    "^mailer[-_]daemon@",
+    "^mailer@",
+    "^listserv@",
+    "^majordom[o]?@",
+    "^mailman@",
+    "^nobody@",
+    "^bounce",
+    "^www(-data)?@",
+    "^mdaemon@",
+    "^root@",
+    "^webmaster@",
+    "^administrator@",
+    "^support@",
+    "^news(letter)?@",
+]
 
 
 # if one of these headers exists, we should not send auto reply
-vacation_ignoreheaderexists = ["list-help",
-                               "list-unsubscribe",
-                               "list-subscribe",
-                               "list-owner",
-                               "list-post",
-                               "list-archive",
-                               "list-id",
-                               "mailing-List",
-                               "x-facebook-notify",
-                               "x-mailing-list",
-                               'x-cron-env',
-                               'x-autoresponse',
-                               'x-eBay-mailtracker'
-                               ]
+vacation_ignoreheaderexists = [
+    "list-help",
+    "list-unsubscribe",
+    "list-subscribe",
+    "list-owner",
+    "list-post",
+    "list-archive",
+    "list-id",
+    "mailing-List",
+    "x-facebook-notify",
+    "x-mailing-list",
+    'x-cron-env',
+    'x-autoresponse',
+    'x-eBay-mailtracker'
+]
 # if these headers exist and match regex, we should not send auto reply
 vacation_ignoreheaderregex = {
     'x-spam-flag': 'yes',
@@ -123,41 +125,36 @@ class VacationReply(object):
 
 if SQL_EXTENSION_ENABLED:
     from sqlalchemy import Table, Column, TEXT, TIMESTAMP, Integer, ForeignKey, Unicode, Boolean
-    from sqlalchemy.ext.declarative import declarative_base
     from sqlalchemy.orm import mapper, relation
-    DeclarativeBase = declarative_base()
     metadata = DeclarativeBase.metadata
 
-    vacation_table = Table("vacation", metadata,
-                           Column('id', Integer, primary_key=True),
-                           Column('created', TIMESTAMP, nullable=False),
-                           Column(
-                               'enabled', Boolean, nullable=False, default=True),
-                           Column('start', TIMESTAMP, nullable=False),
-                           Column('end', TIMESTAMP, nullable=False),
-                           Column(
-                               'awayuser', Unicode(255), unique=True, nullable=False),
-                           Column('subject', Unicode(255), nullable=False),
-                           Column('body', TEXT, nullable=False),
-                           Column('ignoresender', TEXT, nullable=False),
-                           )
+    vacation_table = Table(
+        "vacation", metadata,
+        Column('id', Integer, primary_key=True),
+        Column('created', TIMESTAMP, nullable=False),
+        Column('enabled', Boolean, nullable=False, default=True),
+        Column('start', TIMESTAMP, nullable=False),
+        Column('end', TIMESTAMP, nullable=False),
+        Column('awayuser', Unicode(255), unique=True, nullable=False),
+        Column('subject', Unicode(255), nullable=False),
+        Column('body', TEXT, nullable=False),
+        Column('ignoresender', TEXT, nullable=False),
+    )
 
-    vacationreply_table = Table("vacationreply", metadata,
-                                Column('id', Integer, primary_key=True),
-                                Column(
-                                    'vacation_id', None, ForeignKey('vacation.id')),
-                                Column('sent', TIMESTAMP, nullable=False),
-                                Column(
-                                    'recipient', Unicode(255), nullable=False),
-                                )
+    vacationreply_table = Table(
+        "vacationreply", metadata,
+        Column('id', Integer, primary_key=True),
+        Column('vacation_id', None, ForeignKey('vacation.id')),
+        Column('sent', TIMESTAMP, nullable=False),
+        Column('recipient', Unicode(255), nullable=False),
+        )
     vacation_mapper = mapper(Vacation, vacation_table)
 
-    vacationreply_mapper = mapper(VacationReply, vacationreply_table,
-                                  properties=dict(
-                                      vacation=relation(
-                                          Vacation, backref='replies'),
-                                  )
-                                  )
+    vacationreply_mapper = mapper(
+        VacationReply,
+        vacationreply_table,
+        properties=dict(vacation=relation(Vacation, backref='replies'),)
+    )
 
 
 class VacationCache(object):
