@@ -120,6 +120,17 @@ class FuConfigParser(configparser.RawConfigParser):
     """
     A RawConfigParser with support for comma separated lists of values
     """
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.configpath = None
+        # Markers with default value, put None as value
+        # if there's no default value for a marker
+        self.markers = {
+            '${confdir}': "/etc/fuglu"
+        }
+
+
     def getlist(self,  section, option, separators=',', strip=True, lower=False, **kwargs):
         value = self.get(section, option, **kwargs)
         if value:
@@ -133,6 +144,27 @@ class FuConfigParser(configparser.RawConfigParser):
             valuelist = []
         return valuelist
 
+    def apply_markers(self, inputstring) -> str:
+        """ Replace markers like ${confdir} """
+        outstring = inputstring
+
+        if isinstance(outstring, str):
+            for key, value in self.markers.items():
+                if value is not None:
+                    outstring = outstring.replace(key, value)
+
+        return outstring
+
+    def set_configpath_from_configfile(self, configfile):
+        # Set absolute config path which can be used later in getter
+        # -> For example
+        path, _ = os.path.split(os.path.abspath(configfile))
+        self.markers['${confdir}'] = path
+
+    def get(self, section: str, option: str, *args, **kwargs) -> str:
+        """ Custom get replacing markers like ${confdir} """
+        return self.apply_markers(super().get(section, option, *args, **kwargs))
+
 
 class _SuspectTemplate(Template):
     delimiter = '$'
@@ -236,26 +268,45 @@ def deprecated(func):
         logger.warning('called deprecated function %s' % func.__qualname__)
         return func(*args, **kwargs)
     return deprecated_wrapper
-    
 
-_outgoinghelo = None
-def get_outgoing_helo(config=None):
-    global _outgoinghelo
-    if _outgoinghelo is None:
+
+# Use Class variable to store the outgoing helo globally
+# (Similar to the Singleton implementation)
+class HeloSingleton:
+    _outgoinghelo = None
+
+    @classmethod
+    def outgoinghelo(cls, config):
+        if cls._outgoinghelo is None:
+            if config is None:
+                logging.getLogger('fuglu.HeloSingleton').error("outgoing helo called without config while there's no config defined -> return hostname and don't cache result")
+                return HeloSingleton.__get_outgoing(config=config)
+            else:
+                cls._outgoinghelo = HeloSingleton.__get_outgoing(config=config)
+        return cls._outgoinghelo
+
+    @staticmethod
+    def __get_outgoing(config=None) -> str:
+        outhelo = None
         if config is not None:
             helo = config.get('main', 'outgoinghelo')
             if helo.startswith("$"):
                 # extract target host from environment variable
-                env_helo = os.environ[helo[1:]]
+                env_helo = os.environ[helo[1:].strip()]
                 if not env_helo:
                     raise ValueError(f"Could not extract helo from environment var '{helo}'")
-                _outgoinghelo = env_helo
+                outhelo = env_helo
             elif helo:
-                 _outgoinghelo = helo
-    
-    if _outgoinghelo is None:
-        _outgoinghelo = HOSTNAME
-    return _outgoinghelo
+                outhelo = helo
+
+        if outhelo is None:
+            outhelo = HOSTNAME
+        return outhelo
+
+
+def get_outgoing_helo(config=None):
+    """Use singleton implementation to store outgoing helo"""
+    return HeloSingleton.outgoinghelo(config=config)
 
 
 class Suspect(SimpleTimeoutMixin):
@@ -277,8 +328,8 @@ class Suspect(SimpleTimeoutMixin):
         """holds a copy of the message representation"""
 
         # it's possible to pass ID to suspect
-        id = kwargs.pop('id', None)
-        self.id = id if id else Suspect.generate_id()
+        arg_id = kwargs.pop('id', None)
+        self.id = arg_id if arg_id else Suspect.generate_id()
 
         # store additional keyword parameters
         self.kwargs = kwargs
@@ -751,7 +802,7 @@ class Suspect(SimpleTimeoutMixin):
             # if input is bytes (Py3) we end here
             header_unicode = force_uString(header)
             headerstring = ''.join([force_uString(x[0], encodingGuess=x[1], errors=decode_errors) for x in decode_header(header_unicode)])
-        except Exception as e:
+        except Exception:
             headerstring = header
         return force_uString(headerstring)
 
@@ -856,7 +907,6 @@ class Suspect(SimpleTimeoutMixin):
         #    (because the display name is surrounded by ", otherwise there's no way
         from_headers = [h.replace('\r', '{{CR}}').replace('\n', '{{LF}}') for h in force_uString(from_headers)]
         for display, mailaddress in getaddresses(from_headers):
-            isvalid = True
 
             # after the split, put back the original CR/LF
             if display:
@@ -1123,8 +1173,6 @@ class Suspect(SimpleTimeoutMixin):
         
         Args:
             source (bytes,str,unicode): new message source
-
-        Keyword Args:
             encoding (str): encoding, default is utf-8
             att_mgr_reset (bool): Reset the attachment manager
         """
@@ -1482,7 +1530,7 @@ def extract_domain(address, lowercase=True):
             if lowercase:
                 domain = domain.lower()
             return domain
-        except Exception as e:
+        except Exception:
             raise ValueError("invalid email address: '%s'" % address)
 
 
@@ -2592,7 +2640,7 @@ def create_filehash(fnamelst, hashtype, ashexstr=False):
     Create list of hashes for all files in list
     Args:
         fnamelst (list): list containing filenames
-        fnamelst (hashtype): hashtype
+        hashtype (string): type of hash (e.g. md5, sha1)
         ashexstr (bool): create hex string if true
 
     Raises:
