@@ -184,8 +184,7 @@ class StatsThread(object):
             return
 
         if not os.path.isdir(mrtgdir):
-            self.logger.error(
-                'MRTG directory %s not found, disabling stats writer' % mrtgdir)
+            self.logger.warning('MRTG directory %s not found, disabling stats writer' % mrtgdir)
             return
 
         self.logger.info('Writing statistics to %s' % mrtgdir)
